/virtualbox/{uuid}/suspend — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /virtualbox/{uuid}/suspend

Contents

- /virtualbox/{uuid}/suspend
  - POST /virtualbox/{uuid}/suspend
    - Parameters
    - Response status codes

## POST /virtualbox/{uuid}/suspend

Suspend a VirtualBox VM instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 400: Invalid instance UUID
- 404: Instance doesn’t exist
- 204: Instance suspended

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »